@@ -895,6 +895,13 @@ class BaseScheduler(six.with_metaclass(ABCMeta)):
             'jobstore': (self._jobstore_plugins, self._jobstore_classes, BaseJobStore),
             'executor': (self._executor_plugins, self._executor_classes, BaseExecutor)
         }[type_]
+        print(f"{plugin_container}")
+        print(f"{class_container}")
+        print(f"{base_class}")
+        print(f"{type_}")
+        print(f"{alias}")
+        print(f"{constructor_kwargs}")
+        print(f"-----------------------------")
         try:
             plugin_cls = class_container[alias]
         except KeyError:
