@@ -5,11 +5,12 @@ import six
 from time import time
 
 from uhashring import HashRing
-from apscheduler.jobstores.redis import RedisJobStore
-from apscheduler.schedulers.background import BackgroundScheduler
-from apscheduler.util import ref_to_obj
+from fastapi_crawler_scheduler.apscheduler.jobstores.redis import RedisJobStore
+from fastapi_crawler_scheduler.apscheduler.schedulers.background import BackgroundScheduler
+from fastapi_crawler_scheduler.apscheduler.util import ref_to_obj
 
 from fastapi_crawler_scheduler.service.dbRedisHelper import DbRedisHelper, standard_time
+from fastapi_crawler_scheduler.utils.exception import SchedulerError
 
 setp = 1
 
@@ -78,8 +79,10 @@ class BaseScheduler(object):
             seconds=interval,
         )
         # except Exception as e:
-        #     print(e)
-        #     print("scheduler   add_job 错误")
+        #     # print(e)
+        #     # print("scheduler   add_job 错误")
+        #     # raise Exception
+        #     raise SchedulerError(f"scheduler   add_job 错误 {e}")
 
     def check_process(self) -> None:
         self.redis_db.process_acquire(f'{self.project_name}:node:{self.uuid_number}:{os.getpid()}')
